"""
Name: GALE_Constants.py
Author: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA 
Note: code primarily based on Java GALE authored by Xavier Llor <xllora@illigal.ge.uiuc.edu>
Contact: ryan.j.urbanowicz@darmouth.edu
Created: 2/22/2010
Updated: 10/15/2013
Description: Specifies default GALE run constants.
---------------------------------------------------------------------------------------------------------------------------------------------------------
GALE Version 1.0: A Python implementation of the GALE learning classifier system algorithm implemented for SNP genetic data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python

class CGALEConstants:
    """ Specifies default GALE run constants. """

    #Initialization Parameters
    iAgent = 0.8    #initial fraction of agents filling board
    agentInitWidth = 12 # Initial complexity of agent    
    
    #Major Architectural Parameters
    neighborhood = 1  # r-value from GALE paper.  CHECK THIS!
    dontCare = '#'
        
    #Other Pressure Parameters  
    MergeP = 0.4
    kThreshold = -0.25 #parameter that controls the survival pressure over the current cell 
    P_pickLargerX = 0.5  # probability that after crossover the new agent will be the bigger one
    SomaticMutationP = 0.01 #Probability that a point will be mutated.
    accuracyScaleF = 2 #should be 2  # power to which accuracy is multiplied for scaling accuracy
    MaxSplitP = 0.5 #Also 0.01 - Split probability - may be based on fitness as well 
    
    
    def setConstants(self, prune, wild):
        """ Sets whether pruning is turned on, and the rate at which wilds are incorporated durring mutations. """
        if prune == 0:
            self.Prune = False
        else:
            self.Prune = True
        self.Wild = wild
    
    
GALEConstants = CGALEConstants()
cons = GALEConstants    #To access one of the above constant values from another module, import GALE_Constants * and use "cons.Xconstant"