"""
Name: GALE_Main.py
Author: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA 
Note: code primarily based on Java GALE authored by Xavier Llor <xllora@illigal.ge.uiuc.edu>
Contact: ryan.j.urbanowicz@darmouth.edu
Created: 2/22/2010
Updated: 10/15/2013
Description: Command line Main method for running the GALE algorithm.   Handles inputs, builds the environment, and runs the GALE algorithm
---------------------------------------------------------------------------------------------------------------------------------------------------------
GALE Version 1.0: A Python implementation of the GALE learning classifier system algorithm implemented for SNP genetic data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python

#Import modules
from GALE import *
from GALE_Environment import *
import time
import sys
argv = sys.argv

# *************************************************************************************************
helpstr = """
Parameters:
    1:  Specify the environment - 'gh' - gh = genetic heterogeneity snp datasets with discretely coded genotype attributes and a case/control classes.
    2:  Training Dataset - '/SomePath/SomeTrainfile.txt'
    3:  Testing Dataset - '/SomePath/SomeTestfile.txt'
    4:  Output Filename (Learning Progress Tracking) - '/SomePath/SomeProgressName'
    5:  Output Filename (Final Pop Evaluation) - '/SomePath/SomeFinalPopName'
    6:  Coding Length - '1'
    7:  Dataset Partitions for CV - '10'
    8:  Performance Tracking Cycles - '1'
    9:  Learning iterations - '100.500.1000' or for testing '10.20'
    10: BoardSize (X-axis and Y-axis) - '10', or '25', or '50'
    11: Data Distribution - '0' or '1' or '2' or '3' = uniform, random, pyrimidal, random pyrimidal
    12: Pruning - '0' or '1'
    13: Wild frequency - 0.5, 0.75
"""
# *************************************************************************************************

graphPerformance = False # Built in graphing ability, currently not functional, but mechanism is in place. NOT MEANT TO BE USED ON CLUSTER.
numArgs = len(argv)
print "Arguments: " + str(numArgs)
if numArgs == 14:
    if argv[1] == 'gh': #Different rule representations could be programmed but have not been in this implementation.
        print ("Format Training data: "+argv[2]+"  using a "+argv[6]+" bit coding scheme.")
        
        #Sets up up algorithm to be run.
        GALEConstants.setConstants(int(argv[12]), float(argv[13]))
        e = GALE_Environment(str(argv[2]), str(argv[3]), int(argv[6]))
        sampleSize = e.getNrSamples()
        gale = GALE(e, argv[4], argv[5], int(argv[6]), int(argv[7]), graphPerformance, int(argv[10]), int(argv[10]), int(argv[11]))
        
        #Figure out the iteration stops for evaluation, and the max iterations.
        iterList = argv[9].split('.')
        for i in range(len(iterList)):
            iterList[i] = int(iterList[i])
        lastIter = iterList[len(iterList)-1]
        
        #Set some GALE parameters.
        if argv[9] == 'Default':
            gale.setTrackingIterations(sampleSize)
        else:
            gale.setTrackingIterations(int(argv[8]))   
        gale.setNumberOfTrials(lastIter, iterList)   
        
        #Run the GALE Algorithm 
        gale.runGALE()        
        
    else:
        print "There is no environment handling code for the specified environment"
else:
    print helpstr
    sys.exit()