"""
Name: GALE_RandomDataView.py
Author: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA 
Note: code primarily based on Java GALE authored by Xavier Llor <xllora@illigal.ge.uiuc.edu>
Contact: ryan.j.urbanowicz@darmouth.edu
Created: 2/22/2010
Updated: 10/15/2013
Description: Handles randomized pyrimidal data set distribution.
---------------------------------------------------------------------------------------------------------------------------------------------------------
GALE Version 1.0: A Python implementation of the GALE learning classifier system algorithm implemented for SNP genetic data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python

#Import modules
from random import *

class RandomDataView:
    def __init__(self, dataset, iLb, iUb):
        """ Initialize the data set. """
        self.dataset = dataset
        self.iLowBound = iLb
        self.iUpBound = iUb
        self.iSize = iUb - iLb + 1
        
        
    def getInstance(self, pos):
        """ Returns a random instance of the data set. """
        if pos >= 0 and pos < self.iSize:
            return self.dataset[randint(0,(self.getSize()-1))]
        else:
            return None
    
    #place = randint(0,(self.getSize()-1))
    def getSize(self):
        """ Returns the size of the data set. This may differ per cell using the pyramidal distribution"""
        return self.iSize