"""
Name: GALE_Test.py
Author: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA 
Note: code primarily based on Java GALE authored by Xavier Llor <xllora@illigal.ge.uiuc.edu>
Contact: ryan.j.urbanowicz@darmouth.edu
Created: 2/22/2010
Updated: 10/15/2013
Description: A testing substitute for GALEMain.py to run GALE from Eclipse(with Pydev).
---------------------------------------------------------------------------------------------------------------------------------------------------------
GALE Version 1.0: A Python implementation of the GALE learning classifier system algorithm implemented for SNP genetic data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python

#Import modules
from GALE import *
from GALE_Environment import *
from GALE_Constants import *  

def main():
    """ Runs independently from command line to test the GALE algorithm. """
    graphPerformance = False # Built in graphing ability, currently not functional, but mechanism is in place.
    trainData = "2_1000_0_1600_0_0_CV_0_Train.txt"
    testData = "2_1000_0_1600_0_0_CV_0_Test.txt"
    outProg = "GH_GALE_ProgressTrack"
    outPop = "GH_GALE_PopulationOut"
    bitLength = 1    # This implementation is not yet set up to handle other rule representations, or bit encoding lengths.
    CVpartitions = 10
    trackCycles = 1
    
    iterInput = '5.10.20'  
    xdim = 10
    ydim = 10
    dist = 2
    wild = 0.75
    prune = 1
    
    #Figure out the iteration stops for evaluation, and the max iterations.
    iterList = iterInput.split('.')
    for i in range(len(iterList)):
        iterList[i] = int(iterList[i])
    lastIter = iterList[len(iterList)-1]  

    #Sets up up algorithm to be run.
    GALEConstants.setConstants(prune, wild)
    e = GALE_Environment(trainData,testData,bitLength)
    sampleSize = e.getNrSamples()
    gale = GALE(e, outProg, outPop, bitLength, CVpartitions, graphPerformance, xdim, ydim, dist)
    
    #Set some GALE parameters.
    if trackCycles == 'Default':
        gale.setTrackingIterations(sampleSize)
    else:
        gale.setTrackingIterations(trackCycles) 
    gale.setNumberOfTrials(lastIter, iterList)  
    
    #Run the GALE Algorithm 
    gale.runGALE()
     
if __name__ == '__main__':
    main()